@@ -1,16 +1,16 @@
 "anova.rq" <-
 function (object, ..., test = "Wald", joint = TRUE,
-       score = "tau", se = "nid", R = 200, trim = NULL)
+       score = "tau", se = "nid", iid = TRUE, R = 200, trim = NULL)
 
 {
     if (length(list(object, ...)) > 1) {
 	objects <- list(object, ...)
         return(anova.rqlist(objects, ..., test = test, joint = joint,
-             score = score, se = se, R = R, trim = trim))
+             score = score, se = se, iid = iid, R = R, trim = trim))
     }
     stop("Anova is only defined (yet) for lists of rq objects")
 }
-anova.rqs <- function(object, ..., se = "nid", joint = TRUE){
+anova.rqs <- function(object, ..., se = "nid", iid = TRUE, joint = TRUE){
     class(object) <- "rq"
     m <- length(object$tau)
     z <- rep(list(object), m)
@@ -19,12 +19,12 @@ anova.rqs <- function(object, ..., se = "nid", joint = TRUE){
         z[[i]]$tau <- object$tau[i]
         z[[i]]$rho <- object$rho[i]
     }
-    return(anova.rqlist(z, ..., se = se, joint = joint))
+    return(anova.rqlist(z, ..., se = se, iid = iid, joint = joint))
 }
 
 "anova.rqlist" <-
 function (object, ..., test = "Wald", joint = TRUE, 
-		score = "tau", se = "nid", R = 200, trim = NULL) 
+		score = "tau", se = "nid", iid = TRUE, R = 200, trim = NULL) 
 {
     objects <- object
     responses <- as.character(lapply(objects, function(x) formula(x)[[2]]))
@@ -44,7 +44,7 @@ function (object, ..., test = "Wald", joint = TRUE,
     else
     	names <- lapply(objects, function(x) names(coef(x)))
     if (test == "Wald") 
-        objects <- lapply(objects, function(x) summary(x,se=se,covariance = TRUE))
+        objects <- lapply(objects, function(x) summary(x,se=se,R=R,covariance = TRUE))
     sametaus <- taus == taus[[1]]
     if (all(sametaus)) {
         Tn <- rep(0, nobjects - 1)
@@ -54,15 +54,15 @@ function (object, ..., test = "Wald", joint = TRUE,
         topnote <- paste("Model ", format(1:nobjects), ": ", 
             models, sep = "", collapse = "\n")
         if (test == "anowar") {
-            X1 <- model.matrix(objects[[1]],mf,contrasts=objects[[1]]$contrasts)
+            X1 <- model.matrix(objects[[1]],mf,contrasts.arg=objects[[1]]$contrasts)
             y <- model.response(mf)
 	    weights <- as.vector(model.weights(mf))
             tau <- taus[[1]]
             for (i in 2:nobjects) {
-                if (!all(names[[i]] %in% names[[1]])) 
+		if (!all(sapply(names[[i]], function(x) any(grepl(x, names[[1]], fixed = TRUE))))) 
                   stop("Models aren't nested")
                 mf <- model.frame(objects[[i]])
-                X0 <- model.matrix(objects[[i]], mf,contrasts=objects[[i]]$contrasts)
+                X0 <- model.matrix(objects[[i]], mf,contrasts.arg=objects[[i]]$contrasts)
                 Htest <- rq.test.anowar(X0, X1, y, tau = tau, R = R)
                 ndf[i - 1] <- Htest$ndf
                 Tn[i - 1] <- Htest$Tn
@@ -72,19 +72,19 @@ function (object, ..., test = "Wald", joint = TRUE,
     	table <- data.frame(ndf, ddf, Tn, pvalue)
         }
         else if (test == "rank") {
-            x1 <- model.matrix(objects[[1]],mf,contrasts=objects[[1]]$contrasts)
+            x1 <- model.matrix(objects[[1]],mf,contrasts.arg=objects[[1]]$contrasts)
             y <- model.response(mf)
 	    weights <- as.vector(model.weights(mf))
             for (i in 2:nobjects) {
-                if (!all(names[[i]] %in% names[[1]])) 
+		if (!all(sapply(names[[i]], function(x) any(grepl(x, names[[1]], fixed = TRUE))))) 
                   stop("Models aren't nested")
                 nullH <- is.na(match(names[[1]], names[[i]]))
 		X1 <- as.matrix(x1[, nullH])
                 mf <- model.frame(objects[[i]])
-                X0 <- model.matrix(objects[[i]], mf,contrasts=objects[[i]]$contrasts)
+                X0 <- model.matrix(objects[[i]], mf,contrasts.arg=objects[[i]]$contrasts)
 		if(score == "tau") tau <- taus[[1]]
                 Htest <- rq.test.rank(X0, X1, y, score = score, weights = weights, 
-			tau = tau, trim = trim)
+			iid = iid, tau = tau, trim = trim)
                 ndf[i - 1] <- Htest$ndf
                 Tn[i - 1] <- Htest$Tn
                 ddf[i - 1] <- Htest$ddf
@@ -96,7 +96,7 @@ function (object, ..., test = "Wald", joint = TRUE,
             V <- lapply(objects, function(x) x$cov)
             coef <- lapply(objects, function(x) coef(x)[,1])
             for (i in 2:nobjects) {
-                if (!all(names[[i]] %in% names[[1]])) 
+		if (!all(sapply(names[[i]], function(x) any(grepl(x, names[[1]], fixed = TRUE))))) 
                   stop("Models aren't nested")
                 nullH <- is.na(match(names[[1]], names[[i]]))
                 ndf[i - 1] <- sum(nullH)
