@@ -1,12 +1,12 @@
 c        1         2         3         4         5         6         7
 c23456789012345678901234567890123456789012345678901234567890123456789012
-      subroutine srqfnc(n1,m,nnza1,a1,ja1,ia1,ao1,jao1,iao1,n2,nnza2,
-     &                  a2,ja2,ia2,ao2,jao2,iao2,nnzdmax,d,jd,id,
-     &                  dsub,jdsub,nnzemax,e,je,ie,nnzgmax,g,jg,ig,
-     &                  nnzhmax,h,jh,ih,nsubmax,lindx,xlindx,nnzlmax,
-     &                  lnz,xlnz,iw,iwmax,iwork,xsuper,tmpmax,tmpvec,
-     &                  maxn1n2,ww1,wwm,wwn1,wwn2,cachsz,level,x1,x2,
-     &                  s,u,c1,c2,y,small,ierr,maxit,timewd)
+      subroutine srqfnc(n1,m,nnza1, a1,ja1,ia1, ao1,jao1,iao1, n2,nnza2, ! 11
+     &                  a2,ja2,ia2, ao2,jao2,iao2, nnzdmax, d,jd,id,     ! 21
+     &                  dsub,jdsub, nnzemax, e,je,ie, nnzgmax, g,jg,ig,  ! 31
+     &                  nnzhmax, h,jh,ih, nsubmax, lindx,xlindx,nnzlmax, ! 39
+     &                  lnz,xlnz, iw,iwmax,iwork, xsuper, tmpmax,tmpvec, ! 47
+     &                  maxn1n2, ww1,wwm,wwn1,wwn2, cachsz, level,x1,x2, ! 56
+     &                  s,u,c1,c2, sm_tn_Lrg,   y, ierr,maxit, timewd)   ! 65 ( = MAX_ARGS !)
       integer nnza1,nnza2,m,n1,n2,nnzdmax,nnzemax,nnzgmax,nnzhmax,iwmax,
      &        nnzlmax,nsubmax,cachsz,level,tmpmax,ierr,maxit,maxn1n2,
      &        ja1(nnza1),jao1(nnza1),ja2(nnza2),jao2(nnza2),
@@ -14,7 +14,7 @@ c23456789012345678901234567890123456789012345678901234567890123456789012
      &        ia2(n2+1),iao2(m+1),id(m+1),lindx(nsubmax),xlindx(m+1),
      &        iw(m,5),xlnz(m+1),iwork(iwmax),xsuper(m+1),je(nnzemax),
      &        ie(m+1),jg(nnzgmax),ig(m+1),jh(nnzhmax),ih(m+1)
-      double precision small,
+      double precision sm_tn_Lrg(3), !  := c(small, tiny, Large)
      &                 a1(nnza1),ao1(nnza1),a2(nnza2),ao2(nnza2),
      &                 dsub(nnzhmax+1),d(nnzdmax),g(nnzgmax),
      &                 h(nnzhmax),lnz(nnzlmax),c1(n1),c2(n2),y(m),
@@ -33,9 +33,11 @@ c23456789012345678901234567890123456789012345678901234567890123456789012
      &          ie,nnzgmax,g,jg,ig,nnzhmax,h,jh,ih,wwm(1,4),wwn1(1,4),
      &          wwn2(1,4),wwn1(1,5),wwn1(1,6),wwn2(1,5),wwn1(1,7),
      &          wwn1(1,8),wwn2(1,6),wwn1(1,9),wwn1(1,10),wwn2(1,7),
-     &          maxn1n2,ww1,wwm(1,5),wwm(1,6),small,ierr,maxit,timewd)
+     &     maxn1n2,ww1,wwm(1,5),wwm(1,6), sm_tn_Lrg(1), ierr,maxit,
+     &     timewd, sm_tn_Lrg(2), sm_tn_Lrg(3))
       return
       end
+
 c23456789012345678901234567890123456789012345678901234567890123456789012
       subroutine slpfnc(n1,m,nnza1,a1,ja1,ia1,ao1,jao1,iao1,n2,nnza2,
      &                a2,ja2,ia2,ao2,jao2,iao2,nnzdmax,d,jd,id,dsub,
@@ -47,48 +49,49 @@ c23456789012345678901234567890123456789012345678901234567890123456789012
      &                ie,nnzgmax,g,jg,ig,nnzhmax,h,jh,ih,dy,dx1,
      &                dx2,ds,dz1,dz2,dw,
      &                dxdz1,dxdz2,dsdw,xi1,xi2,
-     &                maxn1n2,ww1,ww2,ww3,small,ierr,maxit,timewd)
+     &                maxn1n2, ww1,ww2,ww3, small, ierr,maxit, timewd,
+     &                tiny, Large)
 c        1         2         3         4         5         6         7
 c23456789012345678901234567890123456789012345678901234567890123456789012
-c Sparse implentation of LMS's interior point method via 
-c    Ng-Peyton's sparse Cholesky factorization for sparse 
+c Sparse implentation of LMS's interior point method via
+c    Ng-Peyton's sparse Cholesky factorization for sparse
 c    symmetric positive definite
 c INPUT:
 c     n1 -- the number of row in the coefficient matrix A1'
 c     m -- the number of column in the coefficient matrix A1'
 c     nnza1 -- the number of non-zero elements in A'
-c     a1 -- an nnza1-vector of non-zero values of the design 
-c          matrix (A1') stored in csr format 
+c     a1 -- an nnza1-vector of non-zero values of the design
+c          matrix (A1') stored in csr format
 c     ja1 -- an nnza1-vector of indices of the non-zero elements of
-c           the coefficient matrix 
+c           the coefficient matrix
 c     ia1 -- an (n1+1)-vector of pointers to the begining of each
 c           row in a1 and ja1
 c     ao1 -- an nnza1-vector of work space for the transpose of
-c           the design matrix stored in csr format or the 
+c           the design matrix stored in csr format or the
 c           design matrix stored in csc format
-c     jao1 -- an nnza1-vector of work space for the indices of the 
-c            transpose of the design matrix 
+c     jao1 -- an nnza1-vector of work space for the indices of the
+c            transpose of the design matrix
 c     iao1 -- an (n1+1)-vector of pointers to the begining of each
 c            column in ao1 and jao1
 c     n2 -- the number of row in the constraint matrix A2'
-c     nnza2 -- the number of non-zero elements in A2' 
-c     a2 -- an nnza2-vector of non-zero values of the contraint 
-c          matrix (A2') stored in csr format 
+c     nnza2 -- the number of non-zero elements in A2'
+c     a2 -- an nnza2-vector of non-zero values of the contraint
+c          matrix (A2') stored in csr format
 c     ja2 -- an nnza2-vector of indices of the non-zero elements of
-c           the constraint matrix 
+c           the constraint matrix
 c     ia2 -- an (n2+1)-vector of pointers to the begining of each
 c           row in a2 and ja2
 c     ao2 -- an nnza2-vector of work space for the transpose of
-c           the constraint matrix stored in csr format or the 
+c           the constraint matrix stored in csr format or the
 c           constraint matrix stored in csc format
-c     jao2 -- an nnza2-vector of work space for the indices of the 
-c            transpose of the constraint matrix 
+c     jao2 -- an nnza2-vector of work space for the indices of the
+c            transpose of the constraint matrix
 c     iao2 -- an (n2+1)-vector of pointers to the begining of each
 c            column in ao2 and jao2
 c     nnzdmax -- upper bound of the non-zero elements in A1A1'
 c     d -- an nnzdmax-vector of non-zero values used to store
-c          the transpose of the design matrix multiplied by the design 
-c          matrix (A1A1') stored in csr format; 
+c          the transpose of the design matrix multiplied by the design
+c          matrix (A1A1') stored in csr format;
 c          also used to store A1Q1^(-1) and A2Q2^(-1) later
 c     jd -- an nnzdmax-vector of indices in d
 c     id -- an (m+1)-vector of pointers to the begining of each
@@ -96,59 +99,59 @@ c           row in d and jd
 c     dsub -- the values of d excluding the diagonal elements
 c     jdsub -- the indices to dsub
 c     nsubmax -- upper bound of the dimension of lindx
-c     lindx -- an nsub-vector of interger which contains, in 
+c     lindx -- an nsub-vector of interger which contains, in
 c           column major order, the row subscripts of the nonzero
 c           entries in L in a compressed storage format
 c     xlindx -- an (m+1)-vector of integer of pointers for lindx
-c     nnzlmax -- the upper bound of the non-zero entries in 
+c     nnzlmax -- the upper bound of the non-zero entries in
 c                L stored in lnz, including the diagonal entries
 c     lnz -- First contains the non-zero entries of d; later
 c            contains the entries of the Cholesky factor
 c     xlnz -- column pointer for L stored in lnz
-c     invp -- an n1-vector of integer of inverse permutation 
+c     invp -- an n1-vector of integer of inverse permutation
 c             vector
 c     perm -- an n1-vector of integer of permutation vector
 c     iw -- integer work array of length m
-c     iwmax -- upper bound of the general purpose integer 
+c     iwmax -- upper bound of the general purpose integer
 c              working storage iwork; set at 7*m+3
 c     iwork -- an iwsiz-vector of integer as work space
-c     colcnt -- array of length m, containing the number of 
+c     colcnt -- array of length m, containing the number of
 c               non-zeros in each column of the factor, including
 c               the diagonal entries
-c     snode -- array of length m for recording supernode 
+c     snode -- array of length m for recording supernode
 c              membership
 c     xsuper -- array of length m+1 containing the supernode
 c               partitioning
-c     split -- an m-vector with splitting of supernodes so that 
+c     split -- an m-vector with splitting of supernodes so that
 c              they fit into cache
 c     tmpmax -- upper bound of the dimension of tmpvec
 c     tmpvec -- a tmpmax-vector of temporary vector
 c     rhs -- m-vector to store the rhs
-c     newrhs -- extra work vector for right-hand side and 
+c     newrhs -- extra work vector for right-hand side and
 c               solution
-c     cachsz -- size of the cache (in kilobytes) on the target 
+c     cachsz -- size of the cache (in kilobytes) on the target
 c               machine
 c     level -- level of loop unrolling while performing numerical
 c              factorization
-c     x1 -- an n1-vector, the initial feasible solution for the primal 
+c     x1 -- an n1-vector, the initial feasible solution for the primal
 c           solution that corresponds to the design matrix A1'
-c     x2 -- an n2-vector, the initial feasible solution for the primal 
+c     x2 -- an n2-vector, the initial feasible solution for the primal
 c           solution that corresponds to the constraint matrix A2'
-c     s -- an n1-vector 
+c     s -- an n1-vector
 c     u -- an n1-vector of the upper bound for x1
-c     c1 -- an n1-vector in the primal; negative response in the 
+c     c1 -- an n1-vector in the primal; negative response in the
 c           regression quantile setting
 c     c2 -- an n2-vector, the negative rhs of the inequality constraint
-c     y -- an m-vector, the initial dual solution 
+c     y -- an m-vector, the initial dual solution
 c     b -- an n1-vector, usualy the rhs of the equality constraint
 c          X'a = (1-tau)X'e in the rq setting
 c     r2 -- an n2-vector of residuals
 c     z1 -- an n1-vector of the dual slack variable
-c     z2 -- an n2-vector 
-c     w -- an n-vector 
-c     q1 -- an n1-vector of work array containing the diagonal 
+c     z2 -- an n2-vector
+c     w -- an n-vector
+c     q1 -- an n1-vector of work array containing the diagonal
 c          elements of the Q1^(-1) matrix
-c     q2 -- an n2-vector of work array containing the diagonal 
+c     q2 -- an n2-vector of work array containing the diagonal
 c          elements of the Q2^(-1) matrix
 c     e -- an nnzdmax-vector containing the non-zero entries of
 c          A1Q1^(-1)A1' stored in csr format
@@ -196,11 +199,11 @@ c       6 -- nsub > nsubmax when calling sfinit
 c       7 -- insufficient work space in iwork when calling symfct
 c       8 -- inconsistancy in input when calling symfct
 c       9 -- tmpsiz > tmpmax when calling symfct; increase tmpmax
-c       10 -- nonpositive diagonal encountered when calling 
+c       10 -- nonpositive diagonal encountered when calling
 c            blkfct
-c       11 -- insufficient work storage in tmpvec when calling 
+c       11 -- insufficient work storage in tmpvec when calling
 c            blkfct
-c       12 -- insufficient work storage in iwork when calling 
+c       12 -- insufficient work storage in iwork when calling
 c            blkfct
 c       13 -- nnzd > nnzdmax in e,je when calling amub
 c       14 -- nnzd > nnzdmax in g,jg when calling amub
@@ -208,6 +211,10 @@ c       15 -- nnzd > nnzdmax in h,jh when calling aplb
 c     maxit -- upper limit of the iteration; on return holds the
 c              number of iterations
 c     timewd -- amount of time to execute this subroutine
+c     tiny  -- tiny number; values below tiny * max(diag) are replaced by 'Large';
+c               was 10^{-30} hardcoded
+c     Large -- Large number ("Infinite") to replace tiny diagonal entries in Cholesky;
+c               was 10^{128}
 c OUTPUT:
 c     y -- an m-vector of primal solution
 c        1         2         3         4         5         6         7
@@ -232,7 +239,7 @@ c23456789012345678901234567890123456789012345678901234567890123456789012
      &                 ds(n1),dz1(n1),dz2(n2),dw(n1),dxdz1(n1),
      &                 dxdz2(n2),dsdw(n1),
      &                 xi1(n1),xi2(n2),ww1(maxn1n2),ww2(m),ww3(m)
-      double precision timewd(7)
+      double precision timewd(7), tiny,Large
       real gtimer,timbeg,timend
       external smxpy1,smxpy2,smxpy4,smxpy8
       external mmpy1,mmpy2,mmpy4,mmpy8
@@ -257,7 +264,7 @@ c  the diagonal matrix Q2^(-1) stored in q2 as an n2-vector,
 c  and store the residuals in r1 in ds, and r3 in dy temporarily,
 c  and r2 in r2 permanently
 c
-c    Call amux to obtain A1x1 and store the value in ww2 
+c    Call amux to obtain A1x1 and store the value in ww2
 c
          call amux(m,x1,ww2,ao1,jao1,iao1)
 c
@@ -283,13 +290,13 @@ c
 c  Obtain AQA = A1Q1^(-1)A1' + A2Q2^(-1)A2' in 5 steps
 c
 c  Step1: Obtain A1Q1^(-1) and store the values in d,jd,id in csr format
-c         Also compute A1Q1^(-1)r1 and store the values in ww2 to be used 
+c         Also compute A1Q1^(-1)r1 and store the values in ww2 to be used
 c         to generate r3;
-c  Step2: Compute A1Q1^(-1)A1' and store the values in e,je,ie 
+c  Step2: Compute A1Q1^(-1)A1' and store the values in e,je,ie
 c  Step3: Obtain A2Q2^(-1) and store the values in d,jd,id in csr format
-c         Also compute A2Q2^(-1)r2 and store the values in in ww3 to 
+c         Also compute A2Q2^(-1)r2 and store the values in in ww3 to
 c         be used to generate r3;
-c  Step4: Compute A2Q2^(-1)A2' and store the value in g,jg,ig 
+c  Step4: Compute A2Q2^(-1)A2' and store the value in g,jg,ig
 c  Step5: Compute AQA and store the values in h,jh,ih
 c
 c    Step 1
@@ -349,7 +356,8 @@ c
          call chlfct(m,xlindx,lindx,invp,perm,iwork,nnzdsub,jdsub,
      &            colcnt,nsuper,snode,xsuper,nnzlmax,nsubmax,xlnz,lnz,
      &            ih,jh,h,cachsz,tmpmax,level,tmpvec,split,ierr,it,
-     &            timewd)
+     &            timewd, tiny,Large)
+
          if (ierr .ne. 0) go to 100
 c
 c Call blkslv: Numerical solution for the new rhs stored in rhs
@@ -388,16 +396,16 @@ c
 c
 c Update mu
 c
-            mu = ddot(n1,z1,1,x1,1) + ddot(n2,z2,1,x2,1) 
+            mu = ddot(n1,z1,1,x1,1) + ddot(n2,z2,1,x2,1)
      &           + ddot(n1,w,1,s,1)
             g1 = mu + deltap*ddot(n1,z1,1,dx1,1)
-     &          + deltad*ddot(n1,dz1,1,x1,1)  
+     &          + deltad*ddot(n1,dz1,1,x1,1)
      &          + deltad*deltap*ddot(n1,dz1,1,dx1,1)
      &          + deltap*ddot(n2,z2,1,dx2,1)
-     &          + deltad*ddot(n2,dz2,1,x2,1)  
+     &          + deltad*ddot(n2,dz2,1,x2,1)
      &          + deltad*deltap*ddot(n2,dz2,1,dx2,1)
      &          + deltap*ddot(n1,w,1,ds,1)
-     &          + deltad*ddot(n1,dw,1,s,1) 
+     &          + deltad*ddot(n1,dw,1,s,1)
      &          + deltad*deltap*ddot(n1,dw,1,ds,1)
             mu = mu*((g1/mu)**3)/(2.d0*dble(n1)+dble(n2))
 c
@@ -454,13 +462,13 @@ c
             do i = 1,n1
                dx1(i) = q1(i) * (dx1(i) - xi1(i) - z1(i) + w(i))
                ds(i) = -dx1(i)
-               dz1(i) = -z1(i) + (mu - z1(i)*dx1(i) 
+               dz1(i) = -z1(i) + (mu - z1(i)*dx1(i)
      &                  - dxdz1(i))/x1(i)
                dw(i) = -w(i) + (mu - w(i)*ds(i) - dsdw(i))/s(i)
             enddo
             do i = 1,n2
                dx2(i) = q2(i) * (dx2(i) - xi2(i) - r2(i))
-               dz2(i) = -z2(i) + (mu - z2(i)*dx2(i) - 
+               dz2(i) = -z2(i) + (mu - z2(i)*dx2(i) -
      &                  dxdz2(i))/x2(i)
             enddo
 c
@@ -479,7 +487,7 @@ c
          call daxpy(n1,deltad,dz1,1,z1,1)
          call daxpy(n2,deltad,dz2,1,z2,1)
          call daxpy(m,deltad,dy,1,y,1)
-         gap = ddot(n1,z1,1,x1,1) + ddot(n2,z2,1,x2,1) + 
+         gap = ddot(n1,z1,1,x1,1) + ddot(n2,z2,1,x2,1) +
      &         ddot(n1,w,1,s,1)
       goto 20
    30 continue
